@@ -1,6 +1,6 @@
 /* utility functions for `patch' */
 
-/* $Id: util.c,v 1.3 2003/02/09 11:10:22 corinna Exp $ */
+/* $Id: util.c,v 1.4 2003/09/07 08:22:05 corinna Exp $ */
 
 /* Copyright (C) 1986 Larry Wall
 
@@ -213,7 +213,7 @@ copy_file (char const *from, char const *to, int to_flags, mode_t mode)
   size_t i;
 
 #ifdef __CYGWIN__
-  if ((fromfd = open (from, O_RDONLY | O_TEXT)) < 0)
+  if ((fromfd = open (from, O_RDONLY | (binary_transput ?: O_TEXT))) < 0)
 #else
   if ((fromfd = open (from, O_RDONLY | O_BINARY)) < 0)
 #endif
